/*******************************************************************************
* File Name: Clock_PA.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_Clock_PA_H)
#define CY_CLOCK_Clock_PA_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void Clock_PA_Start(void) ;
void Clock_PA_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void Clock_PA_StopBlock(void) ;
#endif

void Clock_PA_StandbyPower(uint8 state) ;
void Clock_PA_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 Clock_PA_GetDividerRegister(void) ;
void Clock_PA_SetModeRegister(uint8 modeBitMask) ;
void Clock_PA_ClearModeRegister(uint8 modeBitMask) ;
uint8 Clock_PA_GetModeRegister(void) ;
void Clock_PA_SetSourceRegister(uint8 clkSource) ;
uint8 Clock_PA_GetSourceRegister(void) ;
#if defined(Clock_PA__CFG3)
void Clock_PA_SetPhaseRegister(uint8 clkPhase) ;
uint8 Clock_PA_GetPhaseRegister(void) ;
#endif

#define Clock_PA_Enable()                       Clock_PA_Start()
#define Clock_PA_Disable()                      Clock_PA_Stop()
#define Clock_PA_SetDivider(clkDivider)         Clock_PA_SetDividerRegister(clkDivider, 1)
#define Clock_PA_SetDividerValue(clkDivider)    Clock_PA_SetDividerRegister((clkDivider) - 1, 1)
#define Clock_PA_SetMode(clkMode)               Clock_PA_SetModeRegister(clkMode)
#define Clock_PA_SetSource(clkSource)           Clock_PA_SetSourceRegister(clkSource)
#if defined(Clock_PA__CFG3)
#define Clock_PA_SetPhase(clkPhase)             Clock_PA_SetPhaseRegister(clkPhase)
#define Clock_PA_SetPhaseValue(clkPhase)        Clock_PA_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define Clock_PA_CLKEN              (* (reg8 *) Clock_PA__PM_ACT_CFG)
#define Clock_PA_CLKEN_PTR          ((reg8 *) Clock_PA__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define Clock_PA_CLKSTBY            (* (reg8 *) Clock_PA__PM_STBY_CFG)
#define Clock_PA_CLKSTBY_PTR        ((reg8 *) Clock_PA__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define Clock_PA_DIV_LSB            (* (reg8 *) Clock_PA__CFG0)
#define Clock_PA_DIV_LSB_PTR        ((reg8 *) Clock_PA__CFG0)
#define Clock_PA_DIV_PTR            ((reg16 *) Clock_PA__CFG0)

/* Clock MSB divider configuration register. */
#define Clock_PA_DIV_MSB            (* (reg8 *) Clock_PA__CFG1)
#define Clock_PA_DIV_MSB_PTR        ((reg8 *) Clock_PA__CFG1)

/* Mode and source configuration register */
#define Clock_PA_MOD_SRC            (* (reg8 *) Clock_PA__CFG2)
#define Clock_PA_MOD_SRC_PTR        ((reg8 *) Clock_PA__CFG2)

#if defined(Clock_PA__CFG3)
/* Analog clock phase configuration register */
#define Clock_PA_PHASE              (* (reg8 *) Clock_PA__CFG3)
#define Clock_PA_PHASE_PTR          ((reg8 *) Clock_PA__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define Clock_PA_CLKEN_MASK         Clock_PA__PM_ACT_MSK
#define Clock_PA_CLKSTBY_MASK       Clock_PA__PM_STBY_MSK

/* CFG2 field masks */
#define Clock_PA_SRC_SEL_MSK        Clock_PA__CFG2_SRC_SEL_MASK
#define Clock_PA_MODE_MASK          (~(Clock_PA_SRC_SEL_MSK))

#if defined(Clock_PA__CFG3)
/* CFG3 phase mask */
#define Clock_PA_PHASE_MASK         Clock_PA__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_Clock_PA_H */


/* [] END OF FILE */
