/*******************************************************************************
* File Name: InputClock.c  
* Version 1.70
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "InputClock.h"


/*******************************************************************************
* Function Name: InputClock_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void InputClock_Write(uint8 value) 
{
    uint8 staticBits = InputClock_DR & ~InputClock_MASK;
    InputClock_DR = staticBits | ((value << InputClock_SHIFT) & InputClock_MASK);
}


/*******************************************************************************
* Function Name: InputClock_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void InputClock_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(InputClock_0, mode);
}


/*******************************************************************************
* Function Name: InputClock_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro InputClock_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 InputClock_Read(void) 
{
    return (InputClock_PS & InputClock_MASK) >> InputClock_SHIFT;
}


/*******************************************************************************
* Function Name: InputClock_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 InputClock_ReadDataReg(void) 
{
    return (InputClock_DR & InputClock_MASK) >> InputClock_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(InputClock_INTSTAT) 

    /*******************************************************************************
    * Function Name: InputClock_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 InputClock_ClearInterrupt(void) 
    {
        return (InputClock_INTSTAT & InputClock_MASK) >> InputClock_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
