/*******************************************************************************
* File Name: `$INSTANCE_NAME`.c  
* Version `$CY_MAJOR_VERSION`.`$CY_MINOR_VERSION`
*
* Description:
*  The PhaseAccum Component consists of a 16-bit accumulator that 
*  increments by a configurable increment value.  After each increment
*  the resulting value is shifted right by 6 bits and added to a base
*  register value and sent to the FIFO to be read out.  With this
*  structure the phase accumulator has a 6 bit fractional portion and a
*  10 bit integer portion.
*
* Note:
*
********************************************************************************
* Copyright (2009), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is 
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable 
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction 
* with a Cypress integrated circuit as specified in the applicable agreement. 
* Any reproduction, modification, translation, compilation, or representation of 
* this software except as specified above is prohibited without the express 
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. Use may be 
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/

#include "cytypes.h"
#include "`$INSTANCE_NAME`.h"

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_Init
********************************************************************************
* Summary:
*  The Init function initializes the base address that is added to the
*  accumulated phase.
*
* Parameters:  
*  base - 16-bit lower address of the base address
*
* Return: 
*  void
*
*******************************************************************************/
void `$INSTANCE_NAME`_Init(uint16 base) 
{
	CY_SET_REG16(`$INSTANCE_NAME`_BASE_PTR, base);
}

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_Enable
********************************************************************************
* Summary:
*  Enables the phase accumulator to start operating.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void `$INSTANCE_NAME`_Enable(void)
{
    `$INSTANCE_NAME`_CONTROL |= `$INSTANCE_NAME`_CTRL_ENABLE;
}

/*******************************************************************************
* Function Name: `$INSTANCE_NAME`_WriteIncrement
********************************************************************************
* Summary:
*  This function is used to set the increment value
*
* Parameters:  
*  increment - 16-bit increment value
*
* Return: 
*  void
*
*******************************************************************************/
void `$INSTANCE_NAME`_WriteIncrement(uint16 increment)
{
    CY_SET_REG16(`$INSTANCE_NAME`_INCREMENT_PTR, increment);
}

/* [] END OF FILE */
